@@ -44,17 +44,17 @@ class VariableOsAudio(Variable):
 
     def get(self):
         """
-        pulseaudio по умолчанию если доступно или вписано в /etc/asound.conf
+        pipewire по умолчанию если доступно или вписано в /etc/asound.conf
         """
         avail = [x[0] for x in self.Get('os_audio_available')]
-        if "pulseaudio" in avail:
+        if "pipewire" in avail:
             audio = getValueFromCmdLine(CmdlineParams.Calculate,
                                         CmdlineParams.Audio)
 
             if audio and audio == "alsa":
                 return "alsa"
             else:
-                return "pulseaudio"
+                return "pipewire"
         return "alsa"
 
     def choice(self):
@@ -81,7 +81,7 @@ class VariableOsAudioAvailable(Variable):
     def get(self):
         mapAudioConf = (
             ('alsa', None, _('ALSA')),
-            ('pulseaudio', 'media-sound/pulseaudio', _("PulseAudio")),
+            ('pipewire', 'media-video/pipewire', _("PipeWire")),
         )
         image = self.Get('cl_image')
         if image:
