@@ -917,13 +917,13 @@ class VariableOsLocationBriefData(LocationHelper, TableVariable):
             else:
                 return -1, dev
 
-        devices = map(list, self.ZipVars(
+        devices = list(map(list, self.ZipVars(
             'os_install_disk_dev',
             'os_install_disk_mount',
             'os_install_disk_format',
             'os_install_disk_perform_format',
             'os_install_disk_size',
-            humanreadable=hr))
+            humanreadable=hr)))
 
         binds = [[dev, mp, "", "", ""]
                  for dev, mp in self.ZipVars(
@@ -1126,8 +1126,7 @@ class VariableOsLocationDest(LocationHelper, Variable):
                 return path.normpath(val)
             return val
 
-        value = map(normpath, value)
-        return [x or "/" for x in value]
+        return [x or "/" for x in map(normpath, value)]
 
     def choice(self):
         if self.Get('cl_install_type') == 'flash':
