@@ -61,7 +61,7 @@ class VariableOsInstallLinguas(LocaleVariable):
 
         emerge_config = self.Get('cl_emerge_config')
         if emerge_config and "LINGUAS" in emerge_config:
-            return emerge_config['LINGUAS'].encode('UTF-8')
+            return emerge_config['LINGUAS']
 
         infocommand = ['emerge', '--info']
         defaultLinguas = "bg en de es fr it pl pt_BR nl ru uk"
@@ -333,7 +333,7 @@ class VariableOsInstallClockTimezone(LocaleVariable):
 
         try:
             lang = self.Get(self.locale_varname).split('_')[1]
-            nativeTZ = [x.encode('utf-8') for x in country_timezones[lang]]
+            nativeTZ = [x for x in country_timezones[lang]]
             source = nativeTZ + ["---"] + \
                     sorted([x for x in source if not x in nativeTZ], key=sortkey) 
         except (KeyError, IndexError) as e:
